@@ -13,6 +13,12 @@ class Git(_defaults_.Defaults):
 		defaults=None,
 	):
 
+		# docs.
+		Docs.__init__(self,
+			initialized=True,
+			module="website.git", 
+			notes=[], )
+
 		# defaults.
 		_defaults_.Defaults.__init__(self, traceback="w3bsite.Website.git",)
 		self.assign(defaults.dict())
